@@ -69,34 +69,34 @@ def update_message(message=None, messageType=None):
         message.messageType = messageType
 
 
-def check_message_list_validity(msgList=None, producerConfig=None):
+def check_message_list_validity(msgList=None):
     totalSize = 0
     for message in msgList:
-        check_message_validity(message, producerConfig)
+        check_message_validity(message)
         totalSize += len(message.message)
 
     # is too large, and not just throw exception;
-    if totalSize > producerConfig.get_max_single_msg_bytes() * 2:
+    if totalSize > Constants.TALOS_SINGLE_MESSAGE_BYTES_MAXIMAL * 2:
         raise InvalidArgumentError("Total Messages byte must less than " +
-                                   str(producerConfig.get_max_single_msg_bytes() * 2))
+                                   str(Constants.TALOS_SINGLE_MESSAGE_BYTES_MAXIMAL * 2))
 
 
-def check_message_validity(message=None, producerConfig=None):
-    check_message_len_validity(message, producerConfig)
+def check_message_validity(message=None):
+    check_message_len_validity(message)
     check_message_sequence_number_validity(message)
     check_message_type_validity(message)
 
 
-def check_message_len_validity(message=None, producerConfig=None):
+def check_message_len_validity(message=None):
     if not message.message:
         raise InvalidArgumentError("Field \"message\" must be set")
 
     data = message.message
-    max_bytes = producerConfig.get_max_single_msg_bytes() \
-        if producerConfig != None else Constants.TALOS_SINGLE_MESSAGE_BYTES_MAXIMAL
-    if len(data) > max_bytes or len(data) < Constants.TALOS_SINGLE_MESSAGE_BYTES_MINIMAL:
+    if len(data) > Constants.TALOS_SINGLE_MESSAGE_BYTES_MAXIMAL\
+            or len(data) < Constants.TALOS_SINGLE_MESSAGE_BYTES_MINIMAL:
         raise InvalidArgumentError("Data must be less than or equal to " +
-                                   str(max_bytes) + " bytes, got bytes: " + str(len(data)))
+                                   str(Constants.TALOS_SINGLE_MESSAGE_BYTES_MAXIMAL) +
+                                   " bytes, got bytes: " + str(len(data)))
 
 
 def check_message_sequence_number_validity(message=None):
@@ -198,10 +198,7 @@ def is_offset_out_of_range(throwable=None):
 
 def get_topic_name_by_resource_name(topicTalosResourceName=None):
     itemList = topicTalosResourceName.split(Constants.TALOS_IDENTIFIER_DELIMITER)
-    try:
-        assert len(itemList) >= 3
-    except AssertionError as e:
-        raise e
+    assert len(itemList) >= 3
     return itemList[len(itemList) - 2]
 
 
@@ -253,5 +250,3 @@ def get_host_ip():
         s.close()
     return ip
 
-
-
